/*
 *
 * Copyright © 2015-2016 Antergos
 *
 * style.css
 *
 * This file is part of lightdm-webkit2-greeter
 *
 * lightdm-webkit2-greeter is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License,
 * or any later version.
 *
 * lightdm-webkit2-greeter is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * The following additional terms are in effect as per Section 7 of the license:
 *
 * The preservation of all legal notices and author attributions in
 * the material or in the Appropriate Legal Notices displayed
 * by works containing it is required.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/* Global Styles */

@font-face {
	font-family: 'Open Sans';
	font-weight: 400;
	font-style: normal;
	src: local('Open Sans Regular'), local('Open Sans'), url('../../_vendor/fonts/TTF/OpenSans-Regular.ttf');
}
@font-face {
	font-family: 'Open Sans';
	font-weight: 300;
	font-style: normal;
	src: local('Open Sans Light'), local('Open Sans'), url('../../_vendor/fonts/TTF/OpenSans-Light.ttf');
}

body {
	-webkit-font-smoothing: antialiased !important;
	text-rendering: optimizeLegibility !important;
}

*:focus {
	outline: none;
}

.hidden {
	opacity: 0;
}

::-webkit-scrollbar {
	width: 6px;
}

::-webkit-scrollbar-track {
	background-color: #EAEAEA;
	border-left: 1px solid #CCCCCC;
}

::-webkit-scrollbar-thumb {
	background-color: #5D5D5D;
}

::-webkit-scrollbar-thumb:hover {
	background-color: #757575;
}

.user-wrap2::-webkit-scrollbar {
	width: 4px;
}

.user-wrap2::-webkit-scrollbar-track {
	background-color: #EAEAEA;
	border-left: 1px solid #CCCCCC;
}

.user-wrap2::-webkit-scrollbar-thumb {
	background-color: #5D5D5D;
}

.user-wrap2::-webkit-scrollbar-thumb:hover {
	background-color: #B3B3B3;
}

.close_wallpapers {
	padding: 2px 10px !important;
}

html,
body {
	height: 100%;
	width: 100%;
	background-color: #000000;
	font-family: "Open Sans", sans-serif;
}

i {
	font-size: 17px;
}

h3, .panel-heading {
	font-family: "Open Sans", sans-serif;
	font-size: 16px;
	text-align: center;
	font-weight: 400;
}

a {
	text-decoration: none !important;
}

/* Background Switcher */

.bg-switch {
	position: relative;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	width: 250px;
	margin: 40px auto auto;
	padding: 0px 53px;
	color: #F5F5F5;
}

.bg-switch h3 {
	color: #f5f5f5;
}

.bg-switch .bgs .bg {
	text-align: center;
	text-decoration: none;
	display: block;
	max-height: 95px;
	transition: background 0.4s ease-in;
	margin-bottom: 12px;
}
.bg-switch .bgs .bg:hover {
	background: rgba(255,255,255,0.3);
}

.bg-switch .bgs .bg.active div, .bg-switch .bgs .bg.active img {
	border-color: #d6004b;
}

.bg-switch .bgs .bg div {
	width: 145px;
	height: 95px;
	border: 2px solid #FFFFFF;
	margin-bottom: 10px;
	cursor: pointer;
	transition: all 0.3s linear;
	background-size: cover;
	background-repeat: no-repeat;
}

.hovered {
	text-decoration: none;
	background-color: #ECF0F1;
}

#user-list2 {
	width: 100%;
}

#user-list2 span {
	font-size: 19px;
}

#user-list2 img {
	width: 32px;
	height: 32px;
	margin-right: 10px;
}

#bg-switch-wrapper {
	right: -250px;
	width: 250px;
	background: rgba(0, 0, 0, 0.5);
	position: fixed;
	height: 100%;
	overflow-y: auto;
	z-index: 1000;
	transition: right 0.8s cubic-bezier(0.77, 0, 0.175, 1);
}

.bg-switch-container {
	position: absolute;
	top: 0;
	width: 250px;
	list-style: none;
	margin: 0;
	padding: 0;
}

#bg-switch-toggle {
	top: 0;
	right: -2px;
	position: fixed;
	z-index: 1;
}

#bg-switch-wrapper.active {
	right: 0px;
	width: 250px;
	overflow-x: hidden;
}

.toggle {
	margin: 10px 20px 0 0;
}

/* Full Page Image Header Area */

.header {
	display: table;
	height: 100%;
	width: 100%;
	position: relative;
	background-color: #000000;
	background-size: cover !important;
	background-repeat: no-repeat !important;
	background-position: center !important;
	transition: left 0.8s, background-image 0.3s;
	transition-timing-function: cubic-bezier(0.77, 0, 0.175, 1), linear;

}

#user-target2 {
	position: relative;
}

#user-target2 i {
	right: -21px;
	color: #2C3E50;
	font-size: 14px;
}

#trigger i {
	color: #2C3E50;
	font-size: 14px;
	position: relative;
	top: 10px;
	right: 5px;
}

/* Clock Widget */

.time {
	font-family: "Open Sans", sans-serif;
	font-size: 96px;
	font-weight: 300;
	line-height: 1em;
	text-decoration: none;
	color: #3D73C5;
	background-color: rgb(252, 247, 247);
	transition: 1s ease-out;
	position: relative;
	top: 11px;
}

#panelfix {
	max-height: 178px !important;
	min-height: 178px;
}

.time-panel a {
	display: block;
	-webkit-animation: clkwiggle 7s infinite;
}

.time:hover {
	cursor: pointer;
	color: #77ADFF;
	/* text-shadow: 0px 0px 6px rgba(0, 0, 0, 0.7); */
}

.time-panel {
	background-color: rgb(252, 247, 247) !important;
	border-color: transparent !important;
}

.time-panel:target {
	-webkit-animation: flip 0.5s ease-out;
}

.time-panel:target:after {
	opacity: 0;
}

/* Login Dialog */

.welcome {
	font-weight: 500;
	font-size: 17px;
	position: relative;
	right: 9px;
}

.panel-heading img {
	max-height: 30px;
	width: auto;
}

.login-wrapper {
	list-style-type: none;
	display: table-row;
}

.login-cell {
	display: table-cell;
	vertical-align: middle;
}

.login-box {
	min-height: 275px;
}

#login {
	opacity: 0;
	transition: opacity 0.3s ease-in;
}

#panel-fix .panel-shadow, .panel-group, .panel-shadow {
	box-shadow: none !important;
	border: none !important;
}

#collapseOne {
	position: relative;
	top: 5px;
}

#collapseTwo {
	position: relative;
	top: 15px;
}

.panel-default {
	background-color: rgb(252, 247, 247);
}

.badge {
	color: #2C3E50;
}

.badge, .badge i {
	font-size: 10px !important;
	display: none;
}

.list-group-item.hovered .badge,
.list-group-item.hovered .badge i {
	display: block;
	margin-top: 3px;
}

.panel-heading {
	padding: 10px 20px !important;
	background: #F1F1F1;
	border-bottom-color: rgba(221,221,221, 0.35) !important;
}

.panel-footer {
	height: 50px;
	background: #F1F1F1;
	border-top-color: rgba(221,221,221, 0.35);
}

#accordion {
	margin-bottom: 10px;
}

#sessions, #actionsArea {
	transition: all ease 3s;
}

.panel-body {
	background-color: rgb(252, 247, 247);
	padding: 10px;
}

.panel-footer {
	padding: 5px 15px;
}

.panel-flow {
	overflow: visible !important;
}

.password ul {
	text-align: left;
}

div.password, div.status, div.timer {
	text-align: center;
	position: relative;
	display: none;
	width: 47%;
	margin: 0 auto;
}

#passwordField {
	margin-left: 1px;
}

.input-group-btn {
	width: auto;
}
.form-control {
	border-color: transparent !important;
}

input.password.form-control {
	box-shadow: 0 1px #dddddd;
	margin-top: -1px;
}
input.password.form-control:focus {
	-webkit-box-shadow: inset 0 -2px 0 #2196F3 !important;
	box-shadow: inset 0 -2px 0 #2196F3 !important;
	border-bottom: 2px solid #2196F3 !important;
	margin-top: 0;
}

#passwordArea .btn {
	padding: 7px 12px;
}

#passwordArea .btn-group > .btn {
	float: initial;
}

#logArea {
	position: absolute;
	top: 25%;
	left: 5%;
	width: 25%;
	height: 50%;
	display: none;
	overflow: auto;
	color: #FFFFFF;
	background: rgba(0, 0, 0, 0.6);
	border-radius: 10px;
	font-size: 15px;
	padding: 20px;
}

/* Animation */

@-webkit-keyframes bounce {
	0% {
		-webkit-transform: translateY(0);
	}
	100% {
		-webkit-transform: translateY(-20px);
	}
}

@-webkit-keyframes clkwiggle {
	0% { -webkit-transform: rotate(0deg); }
	1% { -webkit-transform: rotate(-2deg); }
	1.5% { -webkit-transform: rotate(2deg); }
	2% { -webkit-transform: rotate(0deg); }
	2.5% { -webkit-transform: rotate(-2deg); }
	3.5% { -webkit-transform: rotate(2deg); }
	4% { -webkit-transform: rotate(0deg); }
	100% { -webkit-transform: rotate(0deg); }
}

.random {
	background: rgba(111, 111, 111, 0.65);
	text-align: center;
	display: table;
	color: rgba(255, 255, 255, 0.72);
	width: 145px;
	height: 95px;
	border: 2px solid #FFFFFF;
	margin-bottom: 10px;
	cursor: pointer;
	padding-top: 28.5px;
}

.random span {
	font-size: 18px;
}

.random:hover {
	color: white;
	background: rgba(111, 111, 111, 0.85);
}

.random.active {
	border: 2px solid #3D73C5;
}

.user-wrap2 {
	max-width: 50%;
	margin: 0 auto;
	display: -webkit-box;
	overflow: visible;
}

#list-group {
	padding: 0px;
	overflow: visible;
}

@media (max-width: 1900px) {

	.bg-switch {
		position: relative;
		width: 250px;
		margin: 40px auto auto;
		padding: 0px 74px;
	}

	.bg-switch .bgs .bg {
		text-align: center;
		text-decoration: none;
	}

	.bg-switch .bgs .bg img {
		width: 102px;
		height: 67px;
		margin-bottom: 5px;
	}

	h3 {
		margin-top: 10px;
		margin-bottom: 8px;
	}

	#logArea {
		top: 24%;
		left: 2%;
	}

	.random {
		width: 102px;
		height: 67px;
		margin-bottom: 5px;
		padding-top: 18px;
	}
}

.list-group-item {
	padding: 5px 15px;
}

.list-group-item img {
	position: relative;
	bottom: 2px;
}

.list-group-item span:first-of-type {
	position: relative;
	top: 2px;
}

a.list-group-item:focus, a.list-group-item.hovered {
	position: relative;
	box-shadow: 0 2px 2px 0 rgba(0,0,0,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,0,0,.12);
	border-color: transparent;
	outline: none;
	margin: 0px 0;
	background: #FFFFFF;
}

a.list-group-item.hover:not(:focus) {
	background: #f0f0f0;
}

a.list-group-item:focus:before, a.list-group-item:focus:after,
a.list-group-item:hover:before, a.list-group-item:hover:after,
a.list-group-item.hovered:after, a.list-group-item.hovered:before {
	content: "";
	position: absolute;
	z-index: -1;
	top: 0;
	bottom: 0;
	left: 10px;
	right: 10px;
	border-radius: 10px;
}

a.list-group-item:focus:after, a.list-group-item:hover:after, a.list-group-item.hovered:after {
	right: 10px;
	left: auto;
	-webkit-transform: skew(8deg) rotate(3deg);
	transform: skew(8deg) rotate(3deg);
}

.input-group, #passwordArea table {
	width: 100%;
	margin-top: 5px;
}
.modal-title {
	text-align: center;
	padding-top: 20px;
}

.modal-footer {
	text-align: center;
	padding-bottom: 30px;
	padding-left: 25px;
	padding-right: 25px;
}

.modal-header {
	padding-left: 25px;
	padding-right: 25px;
}

#statusArea {
	width: 360px;
	position: relative;
	top: 15px
}

.alert-danger {
	background-color: #e51c23;
}

.alert {
	border: none;
	color: #fff;
	font-size: 14.5px;
	font-weight: 400;
	padding-right: 35px;
	padding-left: 35px;
}

.alert .close {
	color: #fff;
}

.close {
	font-size: 34px;
	font-weight: 300;
	line-height: 24px;
	opacity: 0.6;
	transition: all 0.2s;
}

.alert-dismissible .close {
	position: relative;
	top:      -2px;
	right:    -21px;
}

.close:hover {
	opacity: 1;
}


